@@ -15,7 +15,7 @@ def test_read_mdarray_1():
                                                               output_order="STCZYX",
                                                               output_dask=False,
                                                               chunks_auto=False,
-                                                              remove_Adim=False)
+                                                              remove_adim=False)
 
     assert (dimstring == "STCZYXA")
     assert (mdarray.shape == (2, 1, 2, 1, 1416, 1960, 1))
@@ -24,7 +24,7 @@ def test_read_mdarray_1():
                                                               output_order="STZCYX",
                                                               output_dask=False,
                                                               chunks_auto=False,
-                                                              remove_Adim=True)
+                                                              remove_adim=True)
 
     assert (dimstring == "STZCYX")
     assert (mdarray.shape == (2, 1, 1, 2, 1416, 1960))
@@ -39,7 +39,7 @@ def test_read_mdarray_2():
                                                               output_dask=False,
                                                               chunks_auto=False,
                                                               output_order="STZCYX",
-                                                              remove_Adim=False)
+                                                              remove_adim=False)
 
     assert (dimstring == "STZCYXA")
     assert (mdarray.shape == (2, 1, 1, 2, 1792, 1792, 1))
@@ -48,7 +48,7 @@ def test_read_mdarray_2():
                                                               output_dask=False,
                                                               chunks_auto=False,
                                                               output_order="STCZYX",
-                                                              remove_Adim=True)
+                                                              remove_adim=True)
 
     assert (dimstring == "STCZYX")
     assert (mdarray.shape == (2, 1, 2, 1, 1792, 1792))
@@ -59,14 +59,14 @@ def test_read_mdarray_lazy_1():
     # get the CZI filepath
     filepath = os.path.join(basedir, r"data/w96_A1+A2.czi")
 
-    mdarray, dimstring = pylibczirw_tools.read_mdarray_lazy(filepath, remove_Adim=False)
+    mdarray, dimstring = pylibczirw_tools.read_mdarray_lazy(filepath, remove_adim=False)
 
     assert (dimstring == "STZCYXA")
     assert (mdarray.shape == (2, 1, 1, 2, 1416, 1960, 1))
     assert (mdarray.ndim == 7)
     assert (mdarray.chunksize == (1, 1, 1, 2, 1416, 1960, 1))
 
-    mdarray, dimstring = pylibczirw_tools.read_mdarray_lazy(filepath, remove_Adim=True)
+    mdarray, dimstring = pylibczirw_tools.read_mdarray_lazy(filepath, remove_adim=True)
 
     assert (dimstring == "STZCYX")
     assert (mdarray.shape == (2, 1, 1, 2, 1416, 1960))
@@ -84,7 +84,7 @@ def test_read_mdarray_substack():
                                                               output_order="STCZYX",
                                                               output_dask=False,
                                                               chunks_auto=False,
-                                                              remove_Adim=False,
+                                                              remove_adim=False,
                                                               S=0)
 
     assert (dimstring == "STCZYXA")
@@ -99,7 +99,7 @@ def test_read_mdarray_substack():
                                                               output_order="STZCYX",
                                                               output_dask=True,
                                                               chunks_auto=False,
-                                                              remove_Adim=False,
+                                                              remove_adim=False,
                                                               S=0,
                                                               T=0,
                                                               Z=0)
