@@ -248,6 +248,7 @@ def get_planetable(czifile: str,
 
     # get the czi metadata
     czi_dimensions = czitools.pylibczirw_metadata.CziDimensions(czifile)
+    #czi_dimensions = czimd.CziDimensions(czifile)
     aicsczi = CziFile(czifile)
 
     # initialize the plane table
@@ -313,7 +314,7 @@ def get_planetable(czifile: str,
                                      range(size_z),
                                      range(size_c)):
             sbcount += 1
-            print("Reading sublock : ", sbcount)
+            #print("Reading sublock : ", sbcount)
 
             # get x, y, width and height for a specific tile
             tilebbox = aicsczi.get_mosaic_tile_bounding_box(S=s,
